@@ -411,6 +411,7 @@ function register_Calendar() {
 	};
 	
 	var teamView_enter = function() {
+        jQuery("body, #teamViewQuickConfig").disableSelection();
 	    // trigger selection event
 	    setTimeout(function () {
 	        triggerEvent("SubSelected", []);
@@ -424,6 +425,7 @@ function register_Calendar() {
     };
     
     var teamView_leave = function() {
+        jQuery("body, #teamViewQuickConfig").enableSelection();
         if (calendarhovers["teamday"]) {
             calendarhovers["teamday"].disable();
         }
