@@ -353,7 +353,11 @@ function clearInfoTable(sId) {
 function gridInfoSplitSort_Func(id, order) {
 	var criteria= { "folder_id" : activefolder };
 	gridInfoSplit.disablehover=!configGetKey("gui.effects.hover.infostore");
-    gridInfoSplit.enable(criteria,false);
+	if (infostoreSearchObject !== null) {
+	    searchInfoItem(infostoreSearchObject.module, infostoreSearchObject.pattern);
+	} else {
+	    gridInfoSplit.enable(criteria,false);
+	}
     bInfoSplitLoaded = true;
 }
 
