@@ -1281,6 +1281,8 @@ var setMailHeaderLabel;
         });
     }
 
+    var deleteInProgress = false;
+    
     /**
      * Delete messages
      */
@@ -1298,15 +1300,18 @@ var setMailHeaderLabel;
                 error: setMailHeaderLabel
             });
         }
+        function cb_final() { deleteInProgress = false; }
         // return if ids is empty or a delete is still in progress
-        if (!ids || ids.length == 0) return;
+        if (deleteInProgress || !ids || ids.length == 0) return;
         if (harddelete || configGetKey("mail.deletemail") || configGetKey("mail.folder.trash") == folder) {
             newConfirm(_("Delete E-Mails"),_('Are you sure you want to delete the selected E-Mails?'),AlertPopup.YESNO,null,null,
             function () {
-                OXMailMapping.deleteObjects(ids,true,cb_delete);
+                deleteInProgress = true;
+                OXMailMapping.deleteObjects(ids, true, cb_delete, cb_final);
             }, null);
         } else {
-            OXMailMapping.deleteObjects(ids,false,cb_delete);
+            deleteInProgress = true;
+            OXMailMapping.deleteObjects(ids, false, cb_delete, cb_final);
         }
     };
 
