@@ -1336,8 +1336,7 @@ MailFunctions.prototype = {
                 getStyleTextOfDefaultFont() + '">' +
                 tinyMCE.activeEditor.getContent() + '</body></html>';
         } else {
-            return replaceSpaces(escapeHTML(jQuery('#editor_content').val()),
-                                 true);
+            return replaceSpaces(jQuery('#editor_content').val(), true);
         }
     },
 
