@@ -373,17 +373,17 @@
     Editor.menuSections = {};
     
     Editor.selected = function(count) {
-        var enabled = count == 1;
-        for (var i in Editor.menuSections) {
-            var section = Editor.menuSections[i];
-            //@todo: change to new api
+//        var enabled = count == 1;
+//        for (var i in Editor.menuSections) {
+//            var section = Editor.menuSections[i];
+//            @todo: change to new api
 //            menuglobalzaehler = 0;
 //            menuarrows.messaging[i] = [];
 //            for (var j = 0; j < section.length; j++) {
 //                menu_display_contents("messaging", i, enabled, section[j]);
 //            }
 //            showArrowPopUpMenu(i + ".enhancement", i, "messaging");
-        }
+//        }
     };
     
     Editor.prototype = {
