@@ -354,6 +354,7 @@ SearchListAddressBook.prototype = {
 	},
 	
 	openDiv: function() {
+	    ox.api.setModal(true);
 	    addressbookFolderPath();
 	    centerPopupWindow($(this.floatingpopupdiv));
 	    $(this.floatingpopupdiv).style.display = 'block';
@@ -364,6 +365,7 @@ SearchListAddressBook.prototype = {
 	},
 	
 	closeDiv: function() {
+	    ox.api.setModal(false);
 		this.disableActiveGrids();
 		$(this.floatingpopupdiv).style.display = 'none';
 	},
