@@ -39,7 +39,7 @@ var objTaskDetailParticipants = null;
 var refTaskDetailParticipantTab = null;
 var taskParticipantsGrid = null;
 var taskParticipantsGrid2 = false;
-var tasksFolderPath;
+var tasksFolderPath, tasksSearchObject = null;
 
 var tasksSelection = new Selection();
 var tasksSelection2= new Selection2();
@@ -79,39 +79,19 @@ function() {
             null,
             null,
             function() {
+                tasksSearchObject = null;
                 if (tmpDetailRequest) {
                     OXCache.unregister(tmpDetailRequest.uniqueName);
                     delete(tmpDetailRequest);
                 }
             },
-            function () { 
+            function () {
+                tasksSearchObject = null;
                 triggerEvent('OX_Delete_Search');
                 triggerEvent("Selected",[]);
             }
     );
     
-    registerView("tasks/search",
-         function() { 
-            showNode("taskslist");  
-            $("taskslist").style.display=""; 
-         }, 
-         function() {
-            register("OX_New_Search", taskSearch);
-            register("OX_Delete_Search", taskSearchDelete);
-         }, 
-         function() {
-            if (gridlist.collection) gridlist.disable();
-            unregister("OX_New_Search", taskSearch);
-         },
-         function() { 
-            hideNode("taskslist");  
-            $("taskslist").style.display="none";
-            unregister("OX_Delete_Search", taskSearchDelete);
-            unregister("OX_New_Search", taskSearch);
-         },
-         null
-    );
-    
     registerView("tasks/list",
         function() {
             showNode("taskslist");  
@@ -120,7 +100,11 @@ function() {
         function() {            
             var criteria= { "folder_id" : activefolder };
             gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
-            gridlist.enable(criteria);
+            if (tasksSearchObject !== null) {
+                taskSearch(tasksSearchObject.module, tasksSearchObject.pattern);
+            } else {
+                gridlist.enable(criteria);
+            }
             tasks_setFocus(gridlist);
             register("OX_Print",printTasks);
             register("OX_New_Search", taskSearch);
@@ -143,8 +127,9 @@ function() {
             hideNode("taskslist");  
             $("taskslist").style.display="none";
          },
-         function(changeFolder) { 
+         function(changeFolder) {
             if (changeFolder != undefined) {
+                trigger("OX_Delete_Search");
                 var criteria = { "folder_id" : activefolder };
                 gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
                 gridlist.enable(criteria);
@@ -159,6 +144,9 @@ function() {
                 if ((ox.upsell.isVisible("infostore") && ox.upsell.isVisible("tasks-attachments")) === false) {
                     $("taskpanel4").style.display = "none";
                 }
+                if (!ox.upsell.isVisible("delegate")) {
+                    $("taskpanel2").style.display = "none";
+                }
                 showNode("taskssplit");
                 $("taskssplit").style.display="";
             }, 
@@ -166,7 +154,11 @@ function() {
                 setTabLists(tasksTabsList, tasksPanelsList, tasksEventList);
                 var criteria= { "folder_id" : activefolder };
                 gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
-                gridsplit.enable(criteria);                
+                if (tasksSearchObject !== null) {
+                    taskSearch(tasksSearchObject.module, tasksSearchObject.pattern);
+                } else {
+                    gridsplit.enable(criteria);
+                }
                 // reselect id if it's a direct link for example
                 if (activeTaskId.length && activeTaskId[0].directLink &&
                     activeTaskId[0].id)
@@ -324,6 +316,7 @@ function() {
     
     function taskSearch(module, pattern) {
         if (module != "tasks") { return ; }
+        tasksSearchObject = { module: module, pattern: pattern };
         var criteria= { "folder_id" : activefolder };
         var search= { "note" : "*"+pattern+"*" , "title" : "*"+pattern+"*", "categories" : "*"+pattern+"*" };
         if (currentpath2[1] == "split") {
