@@ -25,21 +25,6 @@
         }
     });
     
-    ox.UI.LimitedPassword = function (text, maxLength) {
-        ox.UI.Password.call(this, text);
-        this.maxLength = maxLength;
-    };
-
-    ox.UI.LimitedPassword.prototype = extend(ox.UI.Password, {
-        addContent: function () {
-            ox.UI.Password.prototype.addContent.apply(this, arguments);
-            // apply limit?
-            if (this.maxLength) {
-                jQuery(this.formnode).attr("maxlength", this.maxLength);
-            }
-        }
-    });
-
 }(jQuery));
 
 register("Ready", function () {
@@ -67,13 +52,13 @@ register("Ready", function () {
         regexp = ox.api.config.get(["modules", NAME, "regexp"], "[^a-z0-9]"),
         special = ox.api.config.get(["modules", NAME, "special"], "$, _, %");
 
-    var pwTooShort = false;
+    var pwTooShort = false, pwTooLong = false;
     
     // new password
-    var pass_new = new ox.UI.LimitedPassword(_("The new password"), maxLength);
+    var pass_new = new ox.UI.Password(_("The new password"));
     page.addWidget(pass_new, "new_password");
      
-    var pass_new2 = new ox.UI.LimitedPassword(_("Confirm new password"), maxLength);
+    var pass_new2 = new ox.UI.Password(_("Confirm new password"));
     page.addWidget(pass_new2, "new_password2");
 
     var text = new ox.UI.Text("");
@@ -105,7 +90,8 @@ register("Ready", function () {
         
         // password strength description
         var levels = {
-            deny: addTranslated(_("Too short")),
+            tooshort: addTranslated(_("Too short")),
+            toolong: addTranslated(_("Too long")),
             veryweak: addTranslated(_("Very weak")),
             weak: addTranslated(_("Weak")),
             good: addTranslated(_("Good")),
@@ -132,7 +118,7 @@ register("Ready", function () {
             webkitBoxShadow: "0px 0px 10px 5px white",
             boxShadow: "0px 0px 10px 5px white",
             cursor: "default"
-        }).append(levels.deny).css({ backgroundColor: "#800" });;
+        }).append(levels.tooshort).css({ backgroundColor: "#800" });;
         
         // analyze strength
         var fnChange = function () {
@@ -144,10 +130,12 @@ register("Ready", function () {
             points = 0 + /[a-z]/.test(val) + /[A-Z]/.test(val) + /[0-9]/.test(val) + (new RegExp(regexp, "i")).test(val);
             // show strength?
             node.empty();
-            pwTooShort = false;
-            if (len < minLength) {
-                node.append(levels.deny).css({ backgroundColor: "#800" });
-                pwTooShort = true;
+            pwTooShort = len < minLength;
+            pwTooLong = len > maxLength;
+            if (pwTooShort) {
+                node.append(levels.tooshort).css({ backgroundColor: "#800" });
+            } else if (pwTooLong) {
+                node.append(levels.toolong).css({ backgroundColor: "#800" });
             } else if (points >= 4 && len >= 10) {
                 node.append(levels.verystrong).css({ backgroundColor: "#808" });
             } else if (points >= 3 && len >= 8) {
@@ -197,13 +185,21 @@ register("Ready", function () {
        		pass_new.formnode.focus();
        		ox.Configuration.error(format(_("Minimum password length is %1$s."), minLength));
        		return;
+        } else if (pwTooLong) {
+            pass_new.formnode.focus();
+            ox.Configuration.error(format(_("Maximum password length is %1$s."), maxLength));
+            return;
         }
 
+    	page.toolbar.disable();
+    	
     	ox.JSON.put(AjaxRoot+"/passwordchange?action=update&session="+session,data,
             function() {
     	        newAlert(_('Password changed'), _("Your new password has been saved. You will be logged out now."), function() {
     	            ox.api.ui.logout({ force: true });
     	        });
+            }, function () {
+                page.toolbar.enable();
             });
     };
 });
